import requests
import os
from ..common import prettyllog
import pprint





import os
import requests

def login():
    baseurl = os.getenv('KALM_SEMAPHORE_URL')
    user = os.getenv('KALM_SEMAPHORE_USER')
    password = os.getenv('KALM_SEMAPHORE_PASSWORD')
    url = f"{baseurl}/api/auth/login"
    headers = {
        'accept': 'application/json',
        'Content-Type': 'application/json'
    }
    data = {
        'auth': user,
        'password': password
    }

    # Create a session
    session = requests.Session()

    # Make the login request
    response = session.post(url, headers=headers, json=data)
    if response.status_code == 204:
        # Successful request
        print("Login successful")
        return session  # Return the session for subsequent requests
    else:
        # Failed request
        print(f"Error: {response.status_code}")
        return None

def get_project(session):
    baseurl = os.getenv('KALM_SEMAPHORE_URL')
    project_url = f"{baseurl}/api/projects"  # Adjust the URL as needed
    headers = {
        'accept': 'application/json',
        'Content-Type': 'application/json'
    }

    # Use the session for the request
    response = session.get(project_url, headers=headers)
    if response.status_code == 200:
        # Successful request
        projects = response.json()
        # map prokects by name
        projects_by_name = {}
        for project in projects:
            projects_by_name[project['name']] = project
        return projects_by_name
    else:
        # Failed request
        print(f"Error: {response.status_code}")

def get_inventory(session, project_id):
    baseurl = os.getenv('KALM_SEMAPHORE_URL')
    inventory_url = f"{baseurl}/api/project/{project_id}/inventory?sort=name&order=asc' "  # Adjust the URL as needed
    headers = {
        'accept': 'application/json',
        'Content-Type': 'application/json'
    }

    # Use the session for the request
    response = session.get(inventory_url, headers=headers)
    print(response.status_code)
    if response.status_code == 200:
        # Successful request
        inventory = response.json()
        # map prokects by name
        inventory_by_name = {}
        for item in inventory:
            inventory_by_name[item['name']] = item
        return inventory_by_name
    else:
        # Failed request
        print(f"Error: {response.status_code}")

def get_inventory_item(session, project_id, inventory_id):
    baseurl = os.getenv('KALM_SEMAPHORE_URL')
    inventory_url = f"{baseurl}/api/projects/{project_id}/inventory/{inventory_id}"  # Adjust the URL as needed
    headers = {
        'accept': 'application/json',
        'Content-Type': 'application/json'
    }

    # Use the session for the request
    response = session.get(inventory_url, headers=headers)
    if response.status_code == 200:
        # Successful request
        inventory = response.json()
        return inventory
    else:
        # Failed request
        print(f"Error: {response.status_code}")

    
def check_env():
    print("check_env")
    if (os.getenv('KALM_SEMAPHORE_URL') == None):
        print("KALM_SEMAPHORE_URL not set")
        return 1
    else:
        print("KALM_SEMAPHORE_URL set to " + os.getenv('KALM_SEMAPHORE_URL'))
        return 0
    

 # Example: Get a list of your projects

def main():
    state = {}
    session = login()
    if session:
        projects = get_project(session)
        print("Projects:", projects)
        for project in projects:
            projectname = project['name']
            state[projectname] = {}
            state[projectname]['project'] = project
            state[projectname]['inventory'] = {}
            inventory = get_inventory(session, projects[project]['id'])
            for item in inventory:
                state[projectname]['inventory'][item] = get_inventory_item(session, projects[project]['id'], inventory[item]['id'])
        pprint.pprint(state)
        



    return 0



import os
from pprint import pprint
import toml 

def major():  
    print("major")
    with open('pyproject.toml', 'r') as toml_file:
        data = toml.load(toml_file)
    # Bump the version numbers
    if 'project' in data and 'version' in data['project']:
        current_version = data['project']['version']
        parts = current_version.split('.')
        if len(parts) == 3:
            major, minor, patch = map(int, parts)
            major += 1
            minor = 0
            patch = 0

            new_version = f'{major}.{minor}.{patch}'
            data['project']['version'] = new_version

    if 'tool' in data and 'poetry' in data['tool'] and 'version' in data['tool']['poetry']:
        current_version = data['tool']['poetry']['version']
        parts = current_version.split('.')
        if len(parts) == 3:
            major, minor, patch = map(int, parts)
            major += 1
            minor = 0
            patch = 0

            new_version = f'{major}.{minor}.{patch}'
            data['tool']['poetry']['version'] = new_version
    # Save the modified pyproject.toml file
    print(data['project']['version'])
    print(data['tool']['poetry']['version'])

    with open('pyproject.toml', 'w') as toml_file:
        toml.dump(data, toml_file)

def minor():
    print("minor")
    with open('pyproject.toml', 'r') as toml_file:
        data = toml.load(toml_file)
    # Bump the version numbers
    if 'project' in data and 'version' in data['project']:
        current_version = data['project']['version']
        parts = current_version.split('.')
        if len(parts) == 3:
            major, minor, patch = map(int, parts)
            minor += 1
            patch = 0

            new_version = f'{major}.{minor}.{patch}'
            data['project']['version'] = new_version

    if 'tool' in data and 'poetry' in data['tool'] and 'version' in data['tool']['poetry']:
        current_version = data['tool']['poetry']['version']
        parts = current_version.split('.')
        if len(parts) == 3:
            major, minor, patch = map(int, parts)
            minor += 1  
            patch = 0

            new_version = f'{major}.{minor}.{patch}'
            data['tool']['poetry']['version'] = new_version
    # Save the modified pyproject.toml file
    print(data['project']['version'])
    print(data['tool']['poetry']['version'])
    with open('pyproject.toml', 'w') as toml_file:
        toml.dump(data, toml_file)


def patch():
  with open('pyproject.toml', 'r') as toml_file:
    data = toml.load(toml_file)

  # Bump the version numbers
  if 'project' in data and 'version' in data['project']:
    current_version = data['project']['version']
    parts = current_version.split('.')
    if len(parts) == 3:
      major, minor, patch = map(int, parts)
      patch += 1
      new_version = f'{major}.{minor}.{patch}'
      data['project']['version'] = new_version

  if 'tool' in data and 'poetry' in data['tool'] and 'version' in data['tool']['poetry']:
    current_version = data['tool']['poetry']['version']
    parts = current_version.split('.')
    if len(parts) == 3:
        major, minor, patch = map(int, parts)
        patch += 1
        new_version = f'{major}.{minor}.{patch}'
        data['tool']['poetry']['version'] = new_version

  # Save the modified pyproject.toml file
  print(data['project']['version'])
  print(data['tool']['poetry']['version'])
  with open('pyproject.toml', 'w') as toml_file:
    toml.dump(data, toml_file)



# keep kalm and con5entrate on your semaphores

from . import serve
import argparse

def main():
    parser = argparse.ArgumentParser(description="Keep kalm and con5entrate on your semaphores", usage="kalm_semaphore <action> \n\n \
\
version : 0.0.2 (semaphore)\n\
actions:\n\
serve      keep kalm and serve semaphore\n\
init       keep kalm and init semaphore systemd service\n\
start      keep kalm and start semaphore systemd service\n\
stop       keep kalm and stop semaphore systemd service\n\
restart    keep kalm and restart semaphore systemd service\n\
setup      keep kalm and setup semaphore\n\
test       keep kalm and test semaphore\n\
audit      keep kalm and audit semaphore\n\
\n\
\
2023 Knowit Miracle\
")
    parser.add_argument('action', metavar='<action>', type=str, nargs='+', help='setup jenkis')
    args = parser.parse_args()
    ready = False

    if args.action[0] == "serve":
        serve.main()
        return 0
    




# main file for semaphore

import os
import sys
import time
import json
import requests
from . import serve

def server():
    print("server")
    return 0

def setup():
    print("setup")
    return 0

def test():
    print("test")
    return 0

def version():
    print("0.0.2")
    return 0

def audit():
    print("audit")
    return 0

def init():
    print("init")
    return 0

def start():
    print("start")
    return 0

def stop():
    print("stop")
    return 0

def restart():
    print("restart")
    return 0




import os
import sys
from ..common import prettyllog




def main():
    prettyllog("ui", "ui", "ui", "new", "000", "ui")
    kalm_ui_port  = os.environ.get("KALM_UI_PORT", "8000")
    kalm_ui_host = os.environ.get("KALM_UI_HOST", "kalm.openknowit.com")
    kalm_ui_debug = os.environ.get("KALM_UI_DEBUG", "True")
    kalm_


                          
